=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2011-04-04 12:12:57 +0000
+++ bzrlib/errors.py	2011-05-08 12:42:43 +0000
@@ -3249,3 +3249,13 @@
     def __init__(self, name, string):
         self.name = name
         self.string = string
+
+
+class NoCompatibleInter(BzrError):
+
+    _fmt = ('No compatible object available for operations from %(source)r '
+            'to %(target)r.')
+
+    def __init__(self, source, target):
+        self.source = source
+        self.target = target

=== modified file 'bzrlib/inter.py'
--- bzrlib/inter.py	2009-03-23 14:59:43 +0000
+++ bzrlib/inter.py	2011-05-08 12:42:43 +0000
@@ -18,6 +18,9 @@
 """Inter-object utility class."""
 
 
+from bzrlib.errors import NoCompatibleInter
+
+
 class InterObject(object):
     """This class represents operations taking place between two objects.
 
@@ -81,7 +84,7 @@
         for provider in reversed(klass._optimisers):
             if provider.is_compatible(source, target):
                 return provider(source, target)
-        return klass(source, target)
+        raise NoCompatibleInter(source, target)
 
     def lock_read(self):
         """Take out a logical read lock.

=== modified file 'doc/en/release-notes/bzr-2.4.txt'
--- doc/en/release-notes/bzr-2.4.txt	2011-05-07 23:58:36 +0000
+++ doc/en/release-notes/bzr-2.4.txt	2011-05-08 12:42:43 +0000
@@ -62,6 +62,10 @@
 * ``annotate_file`` has been deprecated in favor of
   ``annotate_file_revision_tree``. (Jelmer Vernooij, #775598)
 
+* ``Inter.get`` now raises ``NoCompatibleInter`` if there are no
+  compatible optimisers rather than an instance of the class it is called
+  on. (Jelmer Vernooij)
+
 Internals
 *********
 

